// -*- C++ -*-
#ifndef _misc_h_included_
#define _misc_h_included_

class Stamp {
public:
  Stamp();
  Stamp(int n);
  Stamp(const char *s);
  int get_stamp();
  void get_str(char *str);

private:
  int m_stamp;
};

class Ident {
public:
  Ident();
  ~Ident();
  const char *get_name();
  Stamp *get_stamp();
private:
  const char *m_name;
  Stamp *m_stamp;
};

void set_user_name(const char *name);
const char *get_user_name();

#endif
